@@ -5,13 +5,7 @@ import uuid
 import string
 import platform
 import collections
-try:
-    # Python 3
-    from urllib.parse import urlparse, urlencode
-except ImportError:
-    # Python 2
-    from urlparse import urlparse
-    from urllib import urlencode
+from urllib.parse import urlparse, urlencode
 
 import requests
 import unidecode
@@ -24,6 +18,7 @@ from .constants import (
 from .exceptions import UrlError
 
 REMOVED_VALUE = object()
+NOT_SET = object()
 SLUGIFY_WHITELIST = string.ascii_letters + string.digits
 SLUGIFY_SEP_WHITELIST = " ,./\\;:!|*^#@~+-_="
 
@@ -32,6 +27,11 @@ RepresentationParents = collections.namedtuple(
     ("version", "product", "folder", "project")
 )
 
+RepresentationHierarchy = collections.namedtuple(
+    "RepresentationHierarchy",
+    ("project", "folder", "product", "version", "representation")
+)
+
 
 def get_default_timeout():
     """Default value for requests timeout.
@@ -273,7 +273,7 @@ def _try_connect_to_server(url, timeout=None):
     if timeout is None:
         timeout = get_default_timeout()
     try:
-        # TODO add validation if the url lead to Ayon server
+        # TODO add validation if the url lead to AYON server
         #   - this won't validate if the url lead to 'google.com'
         requests.get(url, timeout=timeout)
 
